'use strict';

var winston = require('winston');
var fs = require('fs')
var path = require('path')

//
// Configure CLI output on the default logger
//
winston.cli();

winston.addColors({
    silly: 'magenta',
    debug: 'blue',
    verbose: 'cyan',
    info: 'green',
    warn: 'yellow',
    error: 'red'
});

// winston.remove(winston.transports.Console);

var logger = function(options) {
    var transports = [];

    if (options.console) {
        transports.push(new (winston.transports.Console)({
            timestamp: function() {
                return (new Date()).toISOString().replace(/T/, ' ').replace(/\..+/, '');
            },
            formatter: function(options) {
                // Return string will be passed to logger.
                return winston.config.colorize(
                    options.level,
                    '[' + options.level.toUpperCase() + ']' +
                    '['+ options.timestamp() + '] ' +
                    '[' + (undefined !== options.message ? options.message : '') + ']' +
                    (options.meta && Object.keys(options.meta).length ? '\n'+ JSON.stringify(options.meta) : '' )
                );
            },
            level: options.console.level || 'debug',
            colorize: true,
            prettyPrint: true,
            silent: false
        }));
    }

    if (options.file) {
        var dirname = path.dirname(options.file.filename);
        if (!fs.existsSync(dirname)) {
            fs.mkdirSync(dirname);
        }

        if (!fs.existsSync(options.file.filename)) {
            fs.closeSync(fs.openSync(options.file.filename, 'w'));
        }

        transports.push(new (winston.transports.File)({
            timestamp: function() {
                return (new Date()).toISOString().replace(/T/, ' ').replace(/\..+/, '');
            },
            formatter: function(options) {
                // Return string will be passed to logger.
                return '[' + options.level.toUpperCase() + ']' + '['+ options.timestamp() + '] ' + (undefined !== options.message ? options.message : '') +
                    (options.meta && Object.keys(options.meta).length ? '\n\t'+ JSON.stringify(options.meta) : '' );
            },
            json: false,
            level: options.file.level || 'debug',
            filename: options.file.filename
        }));
    }

    return new (winston.Logger)({
        transports: transports
    });
};

module.exports = logger;
